#
# Cookbook Name:: nagios3
# Recipe:: nagios_client
#
# Copyright 2015, DennyZhang.com
#
# All rights reserved - Do Not Redistribute
#

node.from_file(run_context.resolve_attribute("nagios3", "default"))

case node['platform_family']
when 'debian'
  %w{nagios-nrpe-server nagios-plugins nagios-plugins-basic libsys-statistics-linux-perl}.each do |x|
    apt_package "#{x}" do
      action :install
    end
  end
when 'fedora', 'rhel', 'suse'
  %w{nagios-plugins-nrpe nagios-plugins-all nrpe perl-Sys-Statistics-Linux}.each do |x|
    yum_package "#{x}" do
      action :install
    end
  end

else
  Chef::Application.fatal!("Need to customize for OS of #{node[:platform_family]}")
end

# Make sure nagios user to run admin commands like lsof without problem
file "/etc/sudoers.d/nagios" do
  mode "0440"
  content "%nagios ALL=(ALL:ALL) NOPASSWD: ALL"
end

###################### Install Basic Files for Checks #####################
remote_directory "/etc/nagios/log_cfg" do
  files_mode "0755"
  files_owner "root"
  mode "0755"
  owner "root"
  source "log_cfg"
end
###########################################################################

######################## nagios check plugins ##########################
directory "/etc/nagios/nrpe.d" do
  owner "root"
  group "root"
  mode 0755
  recursive true
  action :create
end

allowed_hosts = node[:nagios][:allowed_hosts] + "," + node[:nagios][:server_ip]
template "/etc/nagios/nrpe.cfg" do
  source "nrpe.cfg.erb"
  owner "root"
  group "root"
  mode 0755
  variables({
              :allowed_hosts => allowed_hosts
            })

  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
end

template "/etc/nagios/nrpe.d/common_nrpe.cfg" do
  source "common_nrpe.cfg.erb"
  owner "root"
  group "root"
  mode 0755
  variables({
              :nagios_plugins => node[:nagios][:plugins_dir]
            })
  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
end

template "/etc/nagios/nrpe.d/my_nrpe.cfg" do
  source "my_nrpe.cfg.erb"
  owner "root"
  group "root"
  mode 0755
  variables({
              :apache_pid_file => node[:nagios][:apache_pid_file],
              :tomcat_cmd_pattern => "tomcat7.*java.*MaxPermSize",
              :hornetq_cmd_pattern => "hornetq.*jnpserver.*beans",
              :search_cmd_pattern => "Search.jar.*search.yml",
              :rest_cmd_pattern => "rest.jar.*rest.yml",
              :rmi_cmd_pattern => "jar.*/ServerStart.jar",
              :adsync_cmd_pattern => "ADSync.jar.*adsync.yml",
              :keystore_cmd_pattern => "KeystoreServerStart.jar.*keystore.yml",
              :neo4j_cmd_pattern => "neo4j-server.*plugins",
              :nagios_plugins => node[:nagios][:plugins_dir],
              :hornetq_ip => "127.0.0.1"
            })
  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
end

template "/etc/nagios/nrpe.d/check_logfile.cfg" do
  source "check_logfile.cfg.erb"
  owner "root"
  group "root"
  mode 0755
  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
  variables({
              :nagios_plugins => node[:nagios][:plugins_dir],
            })
  
  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
end

template "/etc/nagios/nrpe.d/check_port.cfg" do
  source "check_port.cfg.erb"
  owner "root"
  group "root"
  mode 0755
  variables({
              :nagios_plugins => node[:nagios][:plugins_dir],
            })
  notifies :restart, "service[#{node[:nagios][:nrpe_name]}]", :delayed
end

directory "#{node[:nagios][:plugins_dir]}" do
  owner "root"
  group "root"
  mode 0755
  recursive true
  action :create
end

%w{check_proc_mem.sh check_proc_fd.sh check_linux_stats.pl check_ip_address.sh check_ad_test.sh}.each do |x|
  template "#{node[:nagios][:plugins_dir]}/#{x}" do
    source "#{x}.erb"
    owner "root"
    group "root"
    mode 0755
  end
end

# ######################### selenium_test ################################
# remote_file "/opt/selenium-server-standalone-2.38.0.jar" do
#   source "https://selenium.googlecode.com/files/selenium-server-standalone-2.38.0.jar"
#   use_last_modified true
#   mode "0755"
#   action :create_if_missing
# end

########################################################################
# Install plugin of check_logfiles
cookbook_file "#{node[:nagios][:plugins_dir]}/check_logfiles" do
  source "check_logfiles"
  mode '0755'
end

service node[:nagios][:nrpe_name] do
  supports :status => true, :restart => true, :reload => true
  action [ :enable, :start ]
end
