#
# Cookbook Name:: nagios3
# Recipe:: default
#
# Copyright 2015, DennyZhang.com
#
# All rights reserved - Do Not Redistribute
#

node.from_file(run_context.resolve_attribute("nagios3", "default"))

include_recipe "apache2"
# TODO:
#   ln -s  /etc/nagios3/apache2.conf /etc/apache2/conf-enabled/nagios3.conf
########################### Apache Service ###############################

service node[:nagios][:apache_name] do
  action :nothing
end
###########################################################################

########################### Nagios Service ################################
case node['platform_family']
when 'debian'
  %w{nagios3 nagios-nrpe-plugin}.each do |x|
    apt_package "#{x}" do
      action :install
    end
  end

  # Install necessary packages for nagios graph
  %w{librrds-perl libgd-gd2-perl}.each do |x|
    apt_package "#{x}" do
      action :install
    end
  end

  user "nagios" do
    gid "www-data"
  end

  # In Ubuntu, add url alias for http://$server/nagios to /nagios3
  template "/etc/#{node[:nagios][:nagios_name]}/apache2.conf" do
    source "ubuntu_apache2.conf.erb"
    owner "root"
    group "root"
    notifies :restart, "service[#{node[:nagios][:apache_name]}]", :delayed
  end

when 'fedora', 'rhel', 'suse'
  %w{nagios nagios-plugins-all}.each do |x|
    yum_package "#{x}" do
      action :install
    end
  end

  # Install necessary packages for nagios graph
  %w{perl-GD php-gd rrdtool-perl rrdtool-php rrdtool perl-CGI perl-Time-HiRes}.each do |x|
    yum_package "#{x}" do
      action :install
    end
  end
else
  Chef::Application.fatal!("Need to customize for OS of #{node[:platform_family]}")
end

# Nagios: enable external commands
template "/etc/" + node[:nagios][:nagios_name] + "/nagios.cfg" do
  source node[:nagios][:conf_erb_file]
  owner "root"
  group "root"
  mode 0644
  variables({
              :check_external_commands => "1"
            })
  notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
end

# nagios commands.cfg
template node[:nagios][:command_file] do
  source node[:nagios][:command_erb_file]
  owner "root"
  group "root"
  mode 0644
  notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
end

# localhost_nagios cfg
template node[:nagios][:localhost_cfg] do
  source node[:nagios][:localhost_cfg_erb]
  owner "root"
  group "root"
  mode 0644
  notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
end

directory "/var/lib/nagios3/" do
  mode "0750"
  owner "nagios"
  group "nagios"
  action :create
end

template node[:nagios][:htpasswd_users] do
  source "htpasswd.users.erb"
  owner "root"
  group "root"
  mode 0644
  variables({
              :nagios_admin_username => node[:nagios][:admin_username],
              :nagios_admin_password_hash => node[:nagios][:admin_password_hash]
            })
  notifies :restart, "service[#{node[:nagios][:apache_name]}]", :delayed
end

include_recipe "nagios3::nagios_check"

############################# Nagios Graph ################################
nagiosgraph_tar="nagiosgraph-1.4.4.tar.gz"
remote_file "Download nagiosgraph Tarball" do
  path "#{node['nagios']['download_dir']}/#{nagiosgraph_tar}"
  source "http://www.mirrorservice.org/sites/downloads.sourceforge.net/n/na/nagiosgraph/nagiosgraph/1.4.4/nagiosgraph-1.4.4.tar.gz"
  use_last_modified true
  action :create_if_missing
end

execute "Unpack nagiosgraph Tarball" do
  command "tar -xf #{node['nagios']['download_dir']}/#{nagiosgraph_tar}"
  action :run
  only_if { ::File.exists?("#{node['nagios']['download_dir']}/#{nagiosgraph_tar}") \
    && !::File.exists?("#{node['nagios']['download_dir']}/nagiosgraph-1.4.4") }
  cwd node['nagios']['download_dir']
  notifies :run, "execute[Deploy nagiosgraph]", :immediately
end

execute "Deploy nagiosgraph" do
  command <<-EOF
    mkdir -p /usr/local/nagiosgraph/cgi
    mkdir -p /usr/local/nagiosgraph/bin
    mkdir -p /usr/local/nagiosgraph/share
    /bin/cp -vrf etc /usr/local/nagiosgraph/
    sed -i "s#/opt/nagiosgraph/etc#/usr/local/nagiosgraph/etc/#g" cgi/*cgi 
    sed -i "s#/opt/nagiosgraph/etc#/usr/local/nagiosgraph/etc/#g" lib/insert.pl
    /bin/cp cgi/*.cgi /usr/local/nagiosgraph/cgi/
    /bin/cp lib/insert.pl /usr/local/nagiosgraph/bin/
    /bin/cp share/nagiosgraph.css /usr/local/nagiosgraph/share/
    /bin/cp share/nagiosgraph.js /usr/local/nagiosgraph/share/
  EOF
  cwd "#{node['nagios']['download_dir']}/nagiosgraph-1.4.4"
  action :nothing
  not_if { ::File.exists?("/usr/local/nagiosgraph/bin/insert.pl") }
end

directory "/usr/local/nagiosgraph/var/rrd/" do
  mode "0755"
  owner "nagios"
  group "nagios"
  recursive true
  action :create
end

directory "/usr/local/nagiosgraph/etc/" do
  mode "0755"
  owner "nagios"
  group "nagios"
  recursive true
  action :create
end

template "/usr/local/nagiosgraph/etc/nagiosgraph.conf" do
  source "nagiosgraph.conf.erb"
  owner "nagios"
  group "nagios"
  notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
end

# Apache virtual host for graphed service
template "/etc/#{node[:nagios][:apache_name]}/conf.d/nagiosgraph.conf" do
  source "httpd_nagiosgraph.conf"
  owner "root"
  group "root"
  mode 0644
  notifies :restart, "service[#{node[:nagios][:apache_name]}]", :delayed
end

case node['platform_family']
when 'debian'
  # define graphed-service
  template "/etc/#{node[:nagios][:nagios_name]}/conf.d/services_nagios2.cfg" do
    source "ubuntu_services_nagios2.cfg.erb"
    owner "root"
    group "root"
    mode 0644
    notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
  end

  template "/etc/#{node[:nagios][:nagios_name]}/conf.d/extinfo_nagios2.cfg" do
    source "ubuntu_extinfo_nagios2.cfg.erb"
    owner "root"
    group "root"
    mode 0644
    notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
  end

  template "/etc/#{node[:nagios][:nagios_name]}/conf.d/hostgroups_nagios2.cfg" do
    source "ubuntu_hostgroups_nagios2.cfg.erb"
    owner "root"
    group "root"
    mode 0644
    notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
  end

when 'fedora', 'rhel', 'suse'
  # define graphed-service
  template "/etc/#{node[:nagios][:nagios_name]}/objects/templates.cfg" do
    source "redhat_templates.cfg.erb"
    owner "root"
    group "root"
    mode 0644
    notifies :restart, "service[#{node[:nagios][:nagios_name]}]", :delayed
  end
else
  Chef::Application.fatal!("Need to customize for OS of #{node[:platform_family]}")
end
###########################################################################

############################# Nagios Service ##############################
service node[:nagios][:nagios_name] do
  supports :status => true, :restart => true, :reload => true
  action [ :enable, :start ]
end
###########################################################################
